package edu.iesdamiahuguet.gestcentre.jsf;

import edu.iesdamiahuguet.gestcentre.ejb.GestorEntitats;
import edu.iesdamiahuguet.gestcentre.jsf.utils.MissatgesJSF;
import java.io.Serializable;
import java.util.List;

/**
 *
 * @author Climent Cànaves
 */
public abstract class ControladorEntitats<Entitat> implements Serializable {
    private Entitat seleccio = null;
    private Entitat seleccioAnterior = null;
    private boolean edicioActivada = false;
    private boolean novaEntitat = false;

    
        
    public ControladorEntitats() {

    }

    public abstract GestorEntitats<Entitat> getGestor();
    
    public abstract Entitat creaEntitat();
    public abstract Entitat clonaEntitat(Entitat entitat);
    
    public Entitat getSeleccio() {
        return seleccio;
    }

    public void setSeleccio(Entitat seleccio) {
        this.seleccio = seleccio;
    }
    
    
    public boolean isEdicioActivada() {
        return edicioActivada;
    }

    public void setEdicioActivada(boolean edicioActivada) {
        this.edicioActivada = edicioActivada;
    }

    public boolean isNovaEntitat() {
        return novaEntitat;
    }

    public void setNovaEntitat(boolean novaEntitat) {
        this.novaEntitat = novaEntitat;
    }
    
    
    public List<Entitat> getLlista() {
        return getGestor().cercaTots();
    }
    
    public String crea() {       
        try {
            getGestor().crea(seleccio);
            MissatgesJSF.afegeixMissatge(seleccio.getClass().getSimpleName() + "Creada");
            novaEntitat = false;
            edicioActivada = false;
            return "entitatCreada";
        } catch (Exception e) {
            MissatgesJSF.afegeixError("errorCreant" + seleccio.getClass().getSimpleName());
            e.printStackTrace();
            return "error";
        } 
    }
    
    public String actualitza() {
        try {
            getGestor().actualitza(seleccio);
            MissatgesJSF.afegeixMissatge(seleccio.getClass().getSimpleName() + "Desada");
            edicioActivada = false;
            return "entitatDesada";
        } catch (Exception e) {
            MissatgesJSF.afegeixError("errorDesant" + seleccio.getClass().getSimpleName());
            e.printStackTrace();
            return "error";
        } 
    }
    
    public String desa() {
        if (novaEntitat) {
            return crea();
        } else {
            return actualitza();
        }      
    }
    
    public String elimina() {
        try {
            getGestor().elimina(seleccio);
            MissatgesJSF.afegeixMissatge(seleccio.getClass().getSimpleName() + "Eliminada");
            return "entitatEliminada";
        } catch (Exception e) {
             MissatgesJSF.afegeixError("errorEliminant" + seleccio.getClass().getSimpleName());
            return "error";
        }
        
        
    }
    
    public void preparaCreacio() {
        seleccioAnterior = seleccio; 
        
        Entitat seleccio = creaEntitat();
        getGestor().inicialitza(seleccio);

        setSeleccio(seleccio);
                        
        novaEntitat = true;
        edicioActivada = true;
    }
    
    public void preparaEdicio() {
        seleccioAnterior = seleccio;
       
        setSeleccio(clonaEntitat(seleccio));
       
        novaEntitat = false;
        edicioActivada = true;
        
    }
    
    public void cancelaEdicio() {
        setSeleccio(seleccioAnterior);
        
        novaEntitat = false;
        edicioActivada = false;
    }
    

    
    
}
