package edu.iesdamiahuguet.gestcentre.jsf.utils;

import java.util.ResourceBundle;
import javax.faces.application.FacesMessage;
import javax.faces.context.FacesContext;

/**
 * Classe auxiliar per gestionar els missatges que es produeiexen en la capa JSF
 * 
 * @author Climent Cànaves
 */
public class MissatgesJSF {
    
    /**
     * 
     * Retorna un missatge de la font de recursos d'internacionatlizació
     * 
     * @param etiqueta - etiqueta a cercar dins la font de missatges.
     * @return Retorna el missatge amb la internacionalització corresponent
     */
    public static String getEtiqueta(String etiqueta) {
        FacesContext context = FacesContext.getCurrentInstance();
        // Agafam els recurs per internacionalitzar l'aplicacio
        ResourceBundle bundle = context.getApplication().getResourceBundle(context, "missatges");
   
        // Intentam obtenir la etiqueta corresponent des dels recursos
        try {
            return bundle.getString(etiqueta);
        } catch (Exception e) {
            // Si no ha funcionat, retornam l'etiqueta.
            return etiqueta;
        }
    }
    
    /**
     * Afageix un missatge d'informació a la capa JSF
     * @param missatge - missatge a mostrar
     */
    public static void afegeixMissatge(String missatge) {
        FacesContext context = FacesContext.getCurrentInstance();

        
        context.addMessage(null, new FacesMessage(FacesMessage.SEVERITY_INFO, getEtiqueta("informacio"), getEtiqueta(missatge)));
       
    }
    
    /**
     * Afegeix un missatge d'error a la capa JSF
     * @param missatge - missatge d'error a mostrar
     */
    public static void afegeixError(String missatge) {
        FacesContext context = FacesContext.getCurrentInstance();

        context.addMessage(null, new FacesMessage(FacesMessage.SEVERITY_ERROR, getEtiqueta("error"), getEtiqueta(missatge)));
    }
}

