SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0;
SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0;
SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='TRADITIONAL';

DROP SCHEMA IF EXISTS `GestCentre` ;
CREATE SCHEMA IF NOT EXISTS `GestCentre` DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci ;
USE `GestCentre` ;

-- -----------------------------------------------------
-- Table `GestCentre`.`Usuari`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `GestCentre`.`Usuari` (
  `id` VARCHAR(20) NOT NULL ,
  `clau` VARCHAR(32) NULL ,
  `nom` VARCHAR(50) NOT NULL ,
  `data_alta` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ,
  `data_baixa` TIMESTAMP NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `GestCentre`.`Grup_Usuaris`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `GestCentre`.`Grup_Usuaris` (
  `id` VARCHAR(20) NOT NULL ,
  `nom` VARCHAR(50) NOT NULL ,
  `descripcio` VARCHAR(255) NOT NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `GestCentre`.`Grup_Ubicacions_Inventari`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `GestCentre`.`Grup_Ubicacions_Inventari` (
  `id` INT NOT NULL AUTO_INCREMENT ,
  `nom` VARCHAR(50) NOT NULL ,
  `descripcio` VARCHAR(255) NOT NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `GestCentre`.`Ubicacio_Inventari`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `GestCentre`.`Ubicacio_Inventari` (
  `id` INT NOT NULL AUTO_INCREMENT ,
  `nom` VARCHAR(20) NOT NULL ,
  `descripcio` VARCHAR(50) NULL ,
  `grup_ubicacions` INT NOT NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `nom_ubucacio_inventari` (`nom` ASC) ,
  INDEX `fk_Ubicacio_Inventari_Grups_Ubicacions_Inventari1` (`grup_ubicacions` ASC) ,
  CONSTRAINT `fk_Ubicacio_Inventari_Grups_Ubicacions_Inventari1`
    FOREIGN KEY (`grup_ubicacions` )
    REFERENCES `GestCentre`.`Grup_Ubicacions_Inventari` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `GestCentre`.`Propietari_Inventari`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `GestCentre`.`Propietari_Inventari` (
  `id` INT NOT NULL AUTO_INCREMENT ,
  `nom` VARCHAR(20) NOT NULL ,
  `descripcio` VARCHAR(50) NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `idx_nom_proveidor_inventari` (`nom` ASC) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `GestCentre`.`Grup_Categories_Inventari`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `GestCentre`.`Grup_Categories_Inventari` (
  `id` INT NOT NULL AUTO_INCREMENT ,
  `nom` VARCHAR(50) NOT NULL ,
  `descripcio` VARCHAR(255) NOT NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `GestCentre`.`Categoria_Inventari`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `GestCentre`.`Categoria_Inventari` (
  `id` INT NOT NULL AUTO_INCREMENT ,
  `grup_categories` INT NOT NULL ,
  `nom` VARCHAR(50) NOT NULL ,
  `descripcio` VARCHAR(255) NULL ,
  `manteniment` TEXT NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `fk_Categoria_Inventari_Grup_Categories_Inventari1` (`grup_categories` ASC) ,
  CONSTRAINT `fk_Categoria_Inventari_Grup_Categories_Inventari1`
    FOREIGN KEY (`grup_categories` )
    REFERENCES `GestCentre`.`Grup_Categories_Inventari` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `GestCentre`.`Proveidor_Inventari`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `GestCentre`.`Proveidor_Inventari` (
  `id` INT NOT NULL AUTO_INCREMENT ,
  `cif` VARCHAR(9) NOT NULL ,
  `nom` VARCHAR(45) NOT NULL ,
  `descripcio` VARCHAR(255) NULL ,
  `telefon` VARCHAR(45) NULL ,
  `web` VARCHAR(255) NULL ,
  `adreca` VARCHAR(255) NULL ,
  `estat` ENUM('homologat', 'deshomologat', 'ambAvisos') NULL DEFAULT 'homologat' ,
  `data_alta` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ,
  `incidencies` TEXT NULL ,
  `observacions` TEXT NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `idx_nom_propietari_inventari` (`nom` ASC) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `GestCentre`.`Item_Inventari`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `GestCentre`.`Item_Inventari` (
  `id` INT NOT NULL AUTO_INCREMENT ,
  `categoria` INT NOT NULL ,
  `ubicacio` INT NOT NULL ,
  `nom` VARCHAR(45) NOT NULL ,
  `descripcio` TEXT NULL ,
  `observacions` TEXT NULL ,
  `autor` VARCHAR(20) NOT NULL ,
  `data_alta` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ,
  `propietari` INT NOT NULL ,
  `proveidor` INT NOT NULL ,
  `unitats` INT NOT NULL DEFAULT 1 ,
  PRIMARY KEY (`id`) ,
  INDEX `fk_ItemInventari_Ubicacio_Inventari1` (`ubicacio` ASC) ,
  INDEX `fk_ItemInventari_Usuari1` (`autor` ASC) ,
  INDEX `fk_Item_Inventari_Propietari_Inventari1` (`propietari` ASC) ,
  INDEX `fk_Item_Inventari_Categoria_Inventari1` (`categoria` ASC) ,
  INDEX `fk_Item_Inventari_Proveidor_Inventari1` (`proveidor` ASC) ,
  CONSTRAINT `fk_Item_Inventari_Ubicacio_Inventari1`
    FOREIGN KEY (`ubicacio` )
    REFERENCES `GestCentre`.`Ubicacio_Inventari` (`id` )
    ON DELETE RESTRICT
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_Item_Inventari_Usuari1`
    FOREIGN KEY (`autor` )
    REFERENCES `GestCentre`.`Usuari` (`id` )
    ON DELETE RESTRICT
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_Item_Inventari_Propietari_Inventari1`
    FOREIGN KEY (`propietari` )
    REFERENCES `GestCentre`.`Propietari_Inventari` (`id` )
    ON DELETE RESTRICT
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_Item_Inventari_Categoria_Inventari1`
    FOREIGN KEY (`categoria` )
    REFERENCES `GestCentre`.`Categoria_Inventari` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_Item_Inventari_Proveidor_Inventari1`
    FOREIGN KEY (`proveidor` )
    REFERENCES `GestCentre`.`Proveidor_Inventari` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `GestCentre`.`Baixa_Item_Inventari`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `GestCentre`.`Baixa_Item_Inventari` (
  `id` INT NOT NULL ,
  `autor` VARCHAR(20) NOT NULL ,
  `data_baixa` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ,
  `motiu` TEXT NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `fk_BaixaItemInventari_Usuari1` (`autor` ASC) ,
  CONSTRAINT `fk_BaixaItemInventari_Usuari1`
    FOREIGN KEY (`autor` )
    REFERENCES `GestCentre`.`Usuari` (`id` )
    ON DELETE RESTRICT
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_Baixa_Item_Inventari_Item_Inventari1`
    FOREIGN KEY (`id` )
    REFERENCES `GestCentre`.`Item_Inventari` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `GestCentre`.`Revisio_Inventari`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `GestCentre`.`Revisio_Inventari` (
  `id` INT NOT NULL AUTO_INCREMENT ,
  `autor` VARCHAR(20) NOT NULL ,
  `observacions` TEXT NULL ,
  `data` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ,
  `ubicacio` INT NOT NULL ,
  `categoria` INT NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `fk_Revisio_Inventari_Usuari1` (`autor` ASC) ,
  INDEX `fk_Revisio_Inventari_Ubicacio_Inventari1` (`ubicacio` ASC) ,
  INDEX `fk_Revisio_Inventari_Categoria_Inventari1` (`categoria` ASC) ,
  CONSTRAINT `fk_Revisio_Inventari_Usuari1`
    FOREIGN KEY (`autor` )
    REFERENCES `GestCentre`.`Usuari` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_Revisio_Inventari_Ubicacio_Inventari1`
    FOREIGN KEY (`ubicacio` )
    REFERENCES `GestCentre`.`Ubicacio_Inventari` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_Revisio_Inventari_Categoria_Inventari1`
    FOREIGN KEY (`categoria` )
    REFERENCES `GestCentre`.`Categoria_Inventari` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `GestCentre`.`Solicitud_Compra`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `GestCentre`.`Solicitud_Compra` (
  `id` INT NOT NULL AUTO_INCREMENT ,
  `responsable` VARCHAR(20) NOT NULL ,
  `data_solicitud` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ,
  `proveidor` INT NULL ,
  `descripcio` TEXT NOT NULL ,
  `justificacio` TEXT NOT NULL ,
  `observacions` TEXT NULL ,
  `estat` ENUM('solicitada', 'acceptada', 'rebutjada', 'espera', 'tancada') NULL DEFAULT 'solicitada' ,
  `data_resolucio` TIMESTAMP NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `fk_Solicitud_compra_Proveidor_Inventari1` (`proveidor` ASC) ,
  INDEX `fk_Solicitud_compra_Usuari1` (`responsable` ASC) ,
  CONSTRAINT `fk_Solicitud_compra_Proveidor_Inventari1`
    FOREIGN KEY (`proveidor` )
    REFERENCES `GestCentre`.`Proveidor_Inventari` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_Solicitud_compra_Usuari1`
    FOREIGN KEY (`responsable` )
    REFERENCES `GestCentre`.`Usuari` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `GestCentre`.`Macroproces`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `GestCentre`.`Macroproces` (
  `id` INT NOT NULL AUTO_INCREMENT ,
  `codi` VARCHAR(2) NOT NULL ,
  `nom` VARCHAR(45) NOT NULL ,
  `descripcio` VARCHAR(255) NOT NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `GestCentre`.`Proces`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `GestCentre`.`Proces` (
  `id` INT NOT NULL AUTO_INCREMENT ,
  `macroproces` INT NOT NULL ,
  `codi` VARCHAR(4) NOT NULL ,
  `nom` VARCHAR(45) NOT NULL ,
  `descripcio` VARCHAR(255) NOT NULL ,
  `responsable` VARCHAR(20) NOT NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `fk_Proces_Grup_Usuaris1` (`responsable` ASC) ,
  INDEX `fk_Proces_Macroproces1` (`macroproces` ASC) ,
  CONSTRAINT `fk_Proces_Grup_Usuaris1`
    FOREIGN KEY (`responsable` )
    REFERENCES `GestCentre`.`Grup_Usuaris` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_Proces_Macroproces1`
    FOREIGN KEY (`macroproces` )
    REFERENCES `GestCentre`.`Macroproces` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `GestCentre`.`Tipus_Document`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `GestCentre`.`Tipus_Document` (
  `codi` VARCHAR(2) NOT NULL ,
  `nom` VARCHAR(45) NOT NULL ,
  `descripcio` VARCHAR(45) NOT NULL ,
  PRIMARY KEY (`codi`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `GestCentre`.`Document`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `GestCentre`.`Document` (
  `id` INT NOT NULL AUTO_INCREMENT ,
  `tipus` VARCHAR(2) NOT NULL ,
  `proces` INT NOT NULL ,
  `codi` VARCHAR(8) NOT NULL ,
  `nom` VARCHAR(255) NOT NULL ,
  `descripcio` TEXT NOT NULL ,
  `fitxer` BLOB NULL ,
  `data` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ,
  `autor` VARCHAR(20) NOT NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `fk_Document_Tipus_document1` (`tipus` ASC) ,
  INDEX `fk_Document_Usuari1` (`autor` ASC) ,
  INDEX `fk_Document_Proces1` (`proces` ASC) ,
  CONSTRAINT `fk_Document_Tipus_document1`
    FOREIGN KEY (`tipus` )
    REFERENCES `GestCentre`.`Tipus_Document` (`codi` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_Document_Usuari1`
    FOREIGN KEY (`autor` )
    REFERENCES `GestCentre`.`Usuari` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_Document_Proces1`
    FOREIGN KEY (`proces` )
    REFERENCES `GestCentre`.`Proces` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `GestCentre`.`Revisio_Document`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `GestCentre`.`Revisio_Document` (
  `id` INT NOT NULL AUTO_INCREMENT ,
  `document` INT NOT NULL ,
  `revisio` INT NOT NULL ,
  `data` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ,
  `motius` TEXT NOT NULL ,
  `autor` VARCHAR(20) NOT NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `fk_Revisio_Document_Document1` (`document` ASC) ,
  INDEX `fk_Revisio_Document_Usuari1` (`autor` ASC) ,
  CONSTRAINT `fk_Revisio_document_Document1`
    FOREIGN KEY (`document` )
    REFERENCES `GestCentre`.`Document` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_Revisio_document_Usuari1`
    FOREIGN KEY (`autor` )
    REFERENCES `GestCentre`.`Usuari` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `GestCentre`.`Indicador_Control`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `GestCentre`.`Indicador_Control` (
  `id` INT NOT NULL AUTO_INCREMENT ,
  `proces` INT NOT NULL ,
  `codi` VARCHAR(6) NOT NULL ,
  `nom` VARCHAR(45) NOT NULL ,
  `descripcio` VARCHAR(255) NOT NULL ,
  `valorObjectiu` INT NOT NULL ,
  `obsolet` TINYINT(1) NULL ,
  `responsable` VARCHAR(20) NOT NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `fk_Indicador_Control_Proces1` (`proces` ASC) ,
  INDEX `fk_Indicador_Control_Grup_Usuaris1` (`responsable` ASC) ,
  CONSTRAINT `fk_Indicador_control_Proces1`
    FOREIGN KEY (`proces` )
    REFERENCES `GestCentre`.`Proces` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_Indicador_control_Grup_Usuaris1`
    FOREIGN KEY (`responsable` )
    REFERENCES `GestCentre`.`Grup_Usuaris` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `GestCentre`.`Registre_Control`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `GestCentre`.`Registre_Control` (
  `id` INT NOT NULL AUTO_INCREMENT ,
  `indicador` INT NOT NULL ,
  `valor` INT NOT NULL ,
  `valorObjectiu` INT NOT NULL ,
  `comentaris` TEXT NOT NULL ,
  `autor` VARCHAR(20) NOT NULL ,
  `data` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ,
  PRIMARY KEY (`id`) ,
  INDEX `fk_Registre_Control_Indicador_control1` (`indicador` ASC) ,
  INDEX `fk_Registre_Control_Usuari1` (`autor` ASC) ,
  CONSTRAINT `fk_Registre_control_Indicador_control1`
    FOREIGN KEY (`indicador` )
    REFERENCES `GestCentre`.`Indicador_Control` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_Registre_control_Usuari1`
    FOREIGN KEY (`autor` )
    REFERENCES `GestCentre`.`Usuari` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `GestCentre`.`Resposta_Solicitud_Compra`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `GestCentre`.`Resposta_Solicitud_Compra` (
  `solicitud` INT NOT NULL ,
  `responsable` VARCHAR(20) NOT NULL ,
  `data` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ,
  `observacions` TEXT NULL ,
  PRIMARY KEY (`solicitud`) ,
  INDEX `fk_Resposta_Solicitud_Compra_Usuari1` (`responsable` ASC) ,
  CONSTRAINT `fk_Resposta_Solicitud_Compra_Solicitud_Compra1`
    FOREIGN KEY (`solicitud` )
    REFERENCES `GestCentre`.`Solicitud_Compra` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_Resposta_Solicitud_Compra_Usuari1`
    FOREIGN KEY (`responsable` )
    REFERENCES `GestCentre`.`Usuari` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `GestCentre`.`Assignacio_Grup`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `GestCentre`.`Assignacio_Grup` (
  `usuari` VARCHAR(20) NOT NULL ,
  `grup` VARCHAR(20) NOT NULL ,
  PRIMARY KEY (`usuari`, `grup`) ,
  INDEX `fk_table1_Usuari1` (`usuari` ASC) ,
  INDEX `fk_table1_Grup_Usuaris1` (`grup` ASC) ,
  CONSTRAINT `fk_table1_Usuari1`
    FOREIGN KEY (`usuari` )
    REFERENCES `GestCentre`.`Usuari` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_table1_Grup_Usuaris1`
    FOREIGN KEY (`grup` )
    REFERENCES `GestCentre`.`Grup_Usuaris` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `GestCentre`.`Incidencia_Inventari`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `GestCentre`.`Incidencia_Inventari` (
  `id` INT NOT NULL AUTO_INCREMENT ,
  `item` INT NULL ,
  `ubicacio` INT NOT NULL ,
  `autor_obertura` VARCHAR(20) NOT NULL ,
  `data_obertura` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ,
  `descripcio` TEXT NOT NULL ,
  `observacions` TEXT NULL ,
  `autor_tancament` VARCHAR(20) NULL ,
  `data_tancament` TIMESTAMP NULL ,
  `actuacio` TEXT NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `fk_Incidencia_Inventari_Item_Inventari1` (`item` ASC) ,
  INDEX `fk_Incidencia_Inventari_Ubicacio_Inventari1` (`ubicacio` ASC) ,
  INDEX `fk_Incidencia_Inventari_Usuari1` (`autor_obertura` ASC) ,
  INDEX `fk_Incidencia_Inventari_Usuari2` (`autor_tancament` ASC) ,
  CONSTRAINT `fk_Incidencia_Inventari_Item_Inventari1`
    FOREIGN KEY (`item` )
    REFERENCES `GestCentre`.`Item_Inventari` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_Incidencia_Inventari_Ubicacio_Inventari1`
    FOREIGN KEY (`ubicacio` )
    REFERENCES `GestCentre`.`Ubicacio_Inventari` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_Incidencia_Inventari_Usuari1`
    FOREIGN KEY (`autor_obertura` )
    REFERENCES `GestCentre`.`Usuari` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_Incidencia_Inventari_Usuari2`
    FOREIGN KEY (`autor_tancament` )
    REFERENCES `GestCentre`.`Usuari` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;

SET SQL_MODE=@OLD_SQL_MODE;
SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS;
SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS;
